@@ -36,6 +36,7 @@ PACKAGE_TOML_FMT = '''\
 name = "{package_name}"
 version = "0.1.0"
 authors = [{authors}]
+description = "Add a short package description here."
 
 [dependencies]
 # foobar = "*"
@@ -93,10 +94,10 @@ Examples
 .. _buildstatus: https://travis-ci.com/<user>/{package_name}
 '''
 
-LICENSE = '''
+LICENSE = '''\
 The MIT License (MIT)
 
-Copyright (c) 2020 My Name
+Copyright (c) 2020 Mys Lang
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -118,7 +119,7 @@ SOFTWARE.
 '''
 
 LIB_MYS = '''\
-def add(first: int, second: int) -> int:
+def add(first: i32, second: i32) -> i32:
     return first + second
 
 @test
@@ -128,7 +129,7 @@ def test_add():
 
 MAIN_MYS_FMT = '''\
 def main():
-    print('Hello, world!')
+    print("Hello, world!")
 '''
 
 MAKEFILE_FMT = '''\
@@ -446,11 +447,11 @@ def setup_build():
 
 def rename_one_matching(pattern, to):
     paths = glob.glob(pattern)
-    
+
     if len(paths) != 1:
         raise Exception(
             f'{len(paths)} paths are matching when expecting exactly one to match')
-    
+
     os.rename(paths[0], to)
 
 def download_dependency_from_registry(verbose, name, version):
@@ -522,20 +523,26 @@ def find_package_sources(package_name, path, ignore_main=False):
 
     return srcs
 
+def dependency_path(dependency_name, config):
+    for package_name, info in config['dependencies'].items():
+        if package_name == dependency_name:
+            if isinstance(info, str):
+                if info == '*':
+                    return f'build/dependencies/mys-{package_name}-latest/'
+                else:
+                    return f'build/dependencies/mys-{package_name}-{info}/'
+            elif 'path' in info:
+                return info['path']
+            else:
+                raise Exception('Bad dependency format.')
+
+    raise Exception(f'Bad dependency {dependency_name}.')
+
 def find_dependency_sources(config):
     srcs = []
 
     for package_name, info in config['dependencies'].items():
-        if isinstance(info, str):
-            if info == '*':
-                path = f'build/dependencies/mys-{package_name}-latest/'
-            else:
-                path = f'build/dependencies/mys-{package_name}-{info}/'
-        elif 'path' in info:
-            path = info['path']
-        else:
-            raise Exception('Bad dependency format.')
-
+        path = dependency_path(package_name, config)
         srcs += find_package_sources(package_name, path, ignore_main=True)
 
     return srcs
@@ -790,6 +797,15 @@ def do_publish(_parser, args):
     finally:
         os.chdir(path)
 
+def do_style(_parser, _args):
+    config = read_package_configuration()
+
+    print(f'┌───────────────────────────────────────────────────────── {INFO}  ─┐')
+    print('│ This subcommand is not yet implemented.                      │')
+    print('└──────────────────────────────────────────────────────────────┘')
+
+    sys.exit(1)
+
 def do_help(parser, _args):
     parser.print_help()
 
@@ -922,6 +938,14 @@ def main():
                            help='Registry password.')
     subparser.set_defaults(func=do_publish)
 
+    # The style subparser.
+    subparser = subparsers.add_parser(
+        'style',
+        description=(
+            'Check that the package follows the Mys style guidelines. Automatically '
+            'fixes trivial errors and prints the rest.'))
+    subparser.set_defaults(func=do_style)
+
     # The help subparser.
     subparser = subparsers.add_parser(
         'help',
