@@ -17,6 +17,17 @@
 #include <sstream>
 #include <optional>
 
+typedef int8_t i8;
+typedef int16_t i16;
+typedef int32_t i32;
+typedef int64_t i64;
+typedef uint8_t u8;
+typedef uint16_t u16;
+typedef uint32_t u32;
+typedef uint64_t u64;
+typedef float f32;
+typedef double f64;
+
 class String {
 
 public:
@@ -30,12 +41,52 @@ public:
     {
     }
 
-    String(int value) :
+    String(i8 value) :
         m_string(std::make_shared<std::string>(std::to_string(value)))
     {
     }
 
-    String(float value) :
+    String(i16 value) :
+        m_string(std::make_shared<std::string>(std::to_string(value)))
+    {
+    }
+
+    String(i32 value) :
+        m_string(std::make_shared<std::string>(std::to_string(value)))
+    {
+    }
+
+    String(i64 value) :
+        m_string(std::make_shared<std::string>(std::to_string(value)))
+    {
+    }
+
+    String(u8 value) :
+        m_string(std::make_shared<std::string>(std::to_string(value)))
+    {
+    }
+
+    String(u16 value) :
+        m_string(std::make_shared<std::string>(std::to_string(value)))
+    {
+    }
+
+    String(u32 value) :
+        m_string(std::make_shared<std::string>(std::to_string(value)))
+    {
+    }
+
+    String(u64 value) :
+        m_string(std::make_shared<std::string>(std::to_string(value)))
+    {
+    }
+
+    String(f32 value) :
+        m_string(std::make_shared<std::string>(std::to_string(value)))
+    {
+    }
+
+    String(f64 value) :
         m_string(std::make_shared<std::string>(std::to_string(value)))
     {
     }
@@ -252,11 +303,6 @@ public:
     {
     }
 
-    void push_back(const T& item)
-    {
-        m_list->push_back(item);
-    }
-
     T operator[](size_t pos) const
     {
         return m_list->at(pos);
@@ -324,8 +370,8 @@ public:
     }
 
     void append(const T& item)
-    {
-        push_back(item);
+    { 
+        m_list->push_back(item);
     }
 
     int __len__() const
@@ -710,63 +756,77 @@ static inline String chr(int value)
 }
 
 #define assert_eq(v1, v2)                                               \
-    if (!(v1 == v2)) {                                                  \
-        std::cout << "Assert: " << v1 << " != " << v2 << std::endl;     \
+    if (!((v1) == (v2))) {                                              \
+        std::cout << "Assert: " << (v1) << " != " << (v2) << std::endl; \
                                                                         \
         throw AssertionError("assert_eq failed");                       \
     }
 
 #define assert_ne(v1, v2)                                               \
-    if (!(v1 != v2)) {                                                  \
-        std::cout << "Assert: " << v1 << " == " << v2 << std::endl;     \
+    if (!((v1) != (v2))) {                                              \
+        std::cout << "Assert: " << (v1) << " == " << (v2) << std::endl; \
                                                                         \
         throw AssertionError("assert_ne failed");                       \
     }
 
 #define assert_gt(v1, v2)                                               \
-    if (!(v1 > v2)) {                                                   \
-        std::cout << "Assert: " << v1 << " <= " << v2 << std::endl;     \
+    if (!((v1) > (v2))) {                                               \
+        std::cout << "Assert: " << (v1) << " <= " << (v2) << std::endl; \
                                                                         \
         throw AssertionError("assert_gt failed");                       \
     }
 
 #define assert_ge(v1, v2)                                               \
-    if (!(v1 >= v2)) {                                                  \
-        std::cout << "Assert: " << v1 << " < " << v2 << std::endl;      \
+    if (!((v1) >= (v2))) {                                              \
+        std::cout << "Assert: " << (v1) << " < " << (v2) << std::endl;  \
                                                                         \
         throw AssertionError("assert_ge failed");                       \
     }
 
 #define assert_lt(v1, v2)                                               \
-    if (!(v1 < v2)) {                                                   \
-        std::cout << "Assert: " << v1 << " >= " << v2 << std::endl;     \
+    if (!((v1) < (v2))) {                                               \
+        std::cout << "Assert: " << (v1) << " >= " << (v2) << std::endl; \
                                                                         \
         throw AssertionError("assert_lt failed");                       \
     }
 
 #define assert_le(v1, v2)                                               \
-    if (!(v1 <= v2)) {                                                  \
-        std::cout << "Assert: " << v1 << " > " << v2 << std::endl;      \
+    if (!((v1) <= (v2))) {                                              \
+        std::cout << "Assert: " << (v1) << " > " << (v2) << std::endl;  \
                                                                         \
         throw AssertionError("assert_le failed");                       \
     }
 
-#define assert_in(item, iterable)                                       \
-    if (!contains(item, iterable)) {                                    \
-        std::cout                                                       \
-            << "Assert: " << item << " not in " << iterable             \
-            << std::endl;                                               \
-                                                                        \
-        throw AssertionError("assert_in failed");                       \
+#define assert_in(item, iterable)                               \
+    if (!contains((item), (iterable))) {                        \
+        std::cout                                               \
+            << "Assert: " << (item) << " not in " << (iterable) \
+            << std::endl;                                       \
+                                                                \
+        throw AssertionError("assert_in failed");               \
     }
 
 #define assert_not_in(item, iterable)                           \
-    if (contains(item, iterable)) {                             \
+    if (contains((item), (iterable))) {                         \
         std::cout                                               \
-            << "Assert: " << item << " in " << iterable <<      \
-            std::endl;                                          \
+            << "Assert: " << (item) << " in " << (iterable)     \
+            << std::endl;                                       \
                                                                 \
-        throw AssertionError("assert_in failed");               \
+        throw AssertionError("assert_not_in failed");           \
+    }
+
+#define assert_true(value)                                      \
+    if (!(value)) {                                             \
+        std::cout << "Assert: " << (value) << std::endl;        \
+                                                                \
+        throw AssertionError("assert_true failed");             \
+    }
+
+#define assert_false(value)                                     \
+    if (value) {                                                \
+        std::cout << "Assert: " << (value) << std::endl;        \
+                                                                \
+        throw AssertionError("assert_false failed");            \
     }
 
 class Test;
