@@ -16,8 +16,16 @@ from pygments.token import Number
 from pygments.token import Generic
 
 PRIMITIVE_TYPES = set([
-    'int',
-    'float',
+    'i8',
+    'i16',
+    'i32',
+    'i64',
+    'u8',
+    'u16',
+    'u32',
+    'u64',
+    'f32',
+    'f64',
     'bool'
 ])
 
@@ -28,33 +36,8 @@ class LanguageError(Exception):
         self.lineno = lineno
         self.offset = offset
 
-def is_docstring(node):
-    if sys.version_info >= (3, 8):
-        if not isinstance(node, ast.Constant):
-            return False
-
-        if not isinstance(node.value, str):
-            return False
-
-        value = node.value
-    else:
-        if not isinstance(node, ast.Str):
-            return False
-
-        value = node.s
-
-    return not value.startswith('mys-embedded-c++')
-
-def has_docstring(node):
-    if len(node.body) == 0:
-        return False
-
-    first = node.body[0]
-
-    if isinstance(first, ast.Expr):
-        return is_docstring(first.value)
-
-    return False
+def is_relative_import(node):
+    return node.level > 0
 
 def return_type_string(node):
     if isinstance(node, ast.Tuple):
@@ -62,12 +45,12 @@ def return_type_string(node):
 
         for item in node.elts:
             if isinstance(item, ast.Name):
-                if item.id == 'str':
+                if item.id == 'string':
                     types.append('String')
                 else:
                     types.append(item.id)
             elif isinstance(item, ast.Subscript):
-                if item.slice.value.id == 'str':
+                if item.slice.value.id == 'string':
                     types.append('String')
 
         types = ', '.join(types)
@@ -78,19 +61,19 @@ def return_type_string(node):
         item = node.elts[0]
 
         if isinstance(item, ast.Name):
-            if item.id == 'str':
+            if item.id == 'string':
                 type_string = 'String'
             else:
                 type_string = item.id
         elif isinstance(item, ast.Subscript):
-            if item.slice.value.id == 'str':
+            if item.slice.value.id == 'string':
                 type_string = 'String'
 
         return f'List<{type_string}>'
     elif node is None:
         return 'void'
     elif isinstance(node, ast.Name):
-        if node.id == 'str':
+        if node.id == 'string':
             return 'String'
         else:
             return node.id
@@ -101,14 +84,31 @@ def return_type_string(node):
     else:
         return type(node)
 
-def params_string(function_name, args):
-    if not args:
-        return 'void'
-    else:
-        return ', '.join([
-            ParamVisitor(function_name).visit(arg)
-            for arg in args
-        ])
+def params_string(function_name, args, source_lines, defaults=None):
+    if defaults is None:
+        defaults = []
+
+    params = [
+        ParamVisitor(function_name, source_lines).visit(arg)
+        for arg in args
+    ]
+
+    defaults = [
+        BaseVisitor(source_lines).visit(default)
+        for default in defaults
+    ]
+
+    params_with_defaults = params[:len(params) - len(defaults)]
+
+    for param, default in zip(params[-len(defaults):], defaults):
+        params_with_defaults.append(f'{param} = {default}')
+
+    params = ', '.join(params_with_defaults)
+
+    if not params:
+        params = 'void'
+
+    return params
 
 def indent(string):
     return '\n'.join(['    ' + line for line in string.splitlines() if line])
@@ -134,6 +134,7 @@ OPERATORS = {
     ast.BitAnd: '&',
     ast.FloorDiv: '/',
     ast.Not: '!',
+    ast.Invert: '~',
     ast.UAdd: '+',
     ast.USub: '-',
     ast.Is: '==',
@@ -145,6 +146,19 @@ OPERATORS = {
     ast.GtE: '>='
 }
 
+METHOD_OPERATORS = {
+    '__add__': '+',
+    '__sub__': '-',
+    '__iadd__': '+=',
+    '__isub__': '-=',
+    '__eq__': '==',
+    '__ne__': '!=',
+    '__gt__': '>',
+    '__ge__': '>=',
+    '__lt__': '<',
+    '__le__': '<='
+}
+
 def handle_string(value):
     if value.startswith('mys-embedded-c++'):
         return '\n'.join([
@@ -158,9 +172,102 @@ def handle_string(value):
 
 class BaseVisitor(ast.NodeVisitor):
 
+    def __init__(self, source_lines):
+        self.source_lines = source_lines
+
+    def is_string(self, node):
+        line = self.source_lines[node.lineno - 1]
+
+        if line[node.col_offset] != "'":
+            return True
+
+        return False
+
+    def handle_string_node(self, node, value):
+        if self.is_string(node):
+            return handle_string(value)
+        else:
+            raise LanguageError('character literals are not yet supported',
+                                node.lineno,
+                                node.col_offset)
+
+    def is_docstring(self, node):
+        if sys.version_info >= (3, 8):
+            if not isinstance(node, ast.Constant):
+                return False
+
+            if not isinstance(node.value, str):
+                return False
+
+            if not self.is_string(node):
+                return False
+
+            value = node.value
+        else:
+            if not isinstance(node, ast.Str):
+                return False
+
+            if not self.is_string(node):
+                return False
+
+            value = node.s
+
+        return not value.startswith('mys-embedded-c++')
+
+    def has_docstring(self, node):
+        if len(node.body) == 0:
+            return False
+
+        first = node.body[0]
+
+        if isinstance(first, ast.Expr):
+            return self.is_docstring(first.value)
+
+        return False
+
     def visit_Name(self, node):
         return node.id
 
+    def find_print_kwargs(self, node):
+        end = ' << std::endl'
+        flush = None
+
+        for keyword in node.keywords:
+            if keyword.arg == 'end':
+                value = self.visit(keyword.value)
+                end = f' << {value}'
+            elif keyword.arg == 'flush':
+                flush = self.visit(keyword.value)
+            else:
+                raise LanguageError(
+                    f"invalid keyword argument '{keyword.arg}' to print(), only "
+                    "'end' and 'flush' are allowed",
+                    node.lineno,
+                    node.col_offset)
+
+        return end, flush
+
+    def handle_print(self, node, args):
+        end, flush = self.find_print_kwargs(node)
+        code = 'std::cout';
+
+        if len(args) == 1:
+            code += f' << {args[0]}'
+        elif len(args) != 0:
+            first = args[0]
+            args = ' << " " << '.join(args[1:])
+            code += f' << {first} << " " << {args}'
+
+        code += end
+
+        if flush:
+            code += ';\n'
+            code += f'if ({flush}) {{\n'
+            code += f'    std::cout << std::flush;\n'
+            code += '}'
+
+        return code
+
     def visit_Call(self, node):
         function_name = self.visit(node.func)
         args = [
@@ -169,16 +276,9 @@ class BaseVisitor(ast.NodeVisitor):
         ]
 
         if function_name == 'print':
-            if len(args) == 0:
-                code = 'std::cout << std::endl'
-            elif len(args) == 1:
-                code = f'std::cout << {args[0]} << std::endl'
-            else:
-                first = args[0]
-                args = ' << " " << '.join(args[1:])
-                code = f'std::cout << {first} << " " << {args} << std::endl'
+            code = self.handle_print(node, args)
         else:
-            if function_name == 'int':
+            if function_name in ['i8', 'i16', 'i32', 'i64']:
                 function_name = 'to_int'
 
             args = ', '.join(args)
@@ -188,7 +288,7 @@ class BaseVisitor(ast.NodeVisitor):
 
     def visit_Constant(self, node):
         if isinstance(node.value, str):
-            return handle_string(node.value)
+            return self.handle_string_node(node, node.value)
         elif isinstance(node.value, bool):
             return 'true' if node.value else 'false'
         elif isinstance(node.value, float):
@@ -205,7 +305,7 @@ class BaseVisitor(ast.NodeVisitor):
             return str(value)
 
     def visit_Str(self, node):
-        return handle_string(node.s)
+        return self.handle_string_node(node, node.s)
 
     def visit_Bytes(self, node):
         raise LanguageError('bytes() is not yet supported',
@@ -226,7 +326,7 @@ class BaseVisitor(ast.NodeVisitor):
     def visit_BinOp(self, node):
         left = self.visit(node.left)
         right = self.visit(node.right)
-        op_class = node.op.__class__
+        op_class = type(node.op)
 
         if op_class == ast.Pow:
             return f'ipow({left}, {right})'
@@ -236,14 +336,14 @@ class BaseVisitor(ast.NodeVisitor):
             return f'({left} {op} {right})'
 
     def visit_UnaryOp(self, node):
-        op = OPERATORS[node.op.__class__]
+        op = OPERATORS[type(node.op)]
         operand = self.visit(node.operand)
 
-        return f'{op}{operand}'
+        return f'{op}({operand})'
 
     def visit_AugAssign(self, node):
         lval = self.visit(node.target)
-        op = OPERATORS[node.op.__class__]
+        op = OPERATORS[type(node.op)]
         rval = self.visit(node.value)
 
         return f'{lval} {op}= {rval};'
@@ -291,7 +391,7 @@ class BaseVisitor(ast.NodeVisitor):
             return f'{value}.{node.attr}'
 
     def visit_Compare(self, node):
-        op_class = node.ops[0].__class__
+        op_class = type(node.ops[0])
         left = self.visit(node.left)
         right = self.visit(node.comparators[0])
 
@@ -300,7 +400,7 @@ class BaseVisitor(ast.NodeVisitor):
         elif op_class == ast.NotIn:
             return f'!contains({left}, {right})'
         else:
-            return f'{left} {OPERATORS[op_class]} {right}'
+            return f'({left} {OPERATORS[op_class]} {right})'
 
     def visit_If(self, node):
         cond = self.visit(node.test)
@@ -415,7 +515,7 @@ class BaseVisitor(ast.NodeVisitor):
         target = self.visit(node.target)
 
         if isinstance(node.annotation, ast.List):
-            types = params_string('', node.annotation.elts)
+            types = params_string('', node.annotation.elts, self.source_lines)
 
             if isinstance(node.value, ast.Name):
                 value = self.visit(node.value)
@@ -432,7 +532,7 @@ class BaseVisitor(ast.NodeVisitor):
             return f'{target} = {value};'
         elif type_name in PRIMITIVE_TYPES:
             return f'{type_name} {target} = {value};'
-        elif type_name == 'str':
+        elif type_name == 'string':
             return f'String {target}({value});'
         else:
             return f'auto {target} = {type_name}({value});'
@@ -516,6 +616,12 @@ class BaseVisitor(ast.NodeVisitor):
     def visit_FormattedValue(self, node):
         return f'str({self.visit(node.value)})'
 
+    def visit_BoolOp(self, node):
+        values = [self.visit(value) for value in node.values]
+        op = BOOLOPS[type(node.op)]
+
+        return '((' + f') {op} ('.join(values) + '))'
+
     def generic_visit(self, node):
         raise LanguageError('unsupported language construct',
                             node.lineno,
@@ -523,9 +629,10 @@ class BaseVisitor(ast.NodeVisitor):
 
 class HeaderVisitor(BaseVisitor):
 
-    def __init__(self, namespace):
-        super().__init__()
+    def __init__(self, namespace, module_levels, source_lines):
+        super().__init__(source_lines)
         self.namespace = namespace
+        self.module_levels = module_levels
         self.imports = []
         self.other = []
         self.prefix = namespace.replace('::', '_').upper()
@@ -552,20 +659,31 @@ class HeaderVisitor(BaseVisitor):
         ])
 
     def visit_Import(self, node):
-        if len(node.names) != 1:
-            raise LanguageError('import has more than one name')
+        raise LanguageError('use from ... import ...',
+                            node.lineno,
+                            node.col_offset)
 
-        name = node.names[0].name
+    def make_relative_import_absolute(self, module, node):
+        prefix = '.'.join(self.module_levels[0:-node.level])
 
-        if '.' not in name:
-            name += '.lib'
+        if not prefix:
+            raise LanguageError('relative import is outside package',
+                                node.lineno,
+                                node.col_offset)
 
-        module_hpp = name.replace('.', '/')
-        self.imports.append(f'#include "{module_hpp}.mys.hpp"')
+        if module is None:
+            module = prefix
+        else:
+            module = f'{prefix}.{module}'
+
+        return module
 
     def visit_ImportFrom(self, node):
         module = node.module
 
+        if is_relative_import(node):
+            module = self.make_relative_import_absolute(module, node)
+
         if '.' not in module:
             module += '.lib'
 
@@ -573,13 +691,19 @@ class HeaderVisitor(BaseVisitor):
         self.imports.append(f'#include "{module_hpp}.mys.hpp"')
         prefix = 'MYS_' + module.replace('.', '_').upper()
 
-        for name in node.names:
-            if name.asname:
-                asname = name.asname
-            else:
-                asname = name.name
+        if len(node.names) != 1:
+            raise LanguageError(f'only one import is allowed, found {len(node.names)}',
+                                node.lineno,
+                                node.col_offset)
 
-            self.other.append(f'{prefix}_{name.name}_IMPORT_AS({asname});')
+        name = node.names[0]
+
+        if name.asname:
+            asname = name.asname
+        else:
+            asname = name.name
+
+        self.other.append(f'{prefix}_{name.name}_IMPORT_AS({asname});')
 
     def visit_ClassDef(self, node):
         # MYS_TIMER_LIB_Timer_IMPORT_AS(__name__) \
@@ -589,7 +713,10 @@ class HeaderVisitor(BaseVisitor):
     def visit_FunctionDef(self, node):
         function_name = node.name
         return_type = return_type_string(node.returns)
-        params = params_string(function_name, node.args.args)
+        params = params_string(function_name,
+                               node.args.args,
+                               self.source_lines,
+                               node.args.defaults)
 
         if function_name == 'main':
             return
@@ -621,6 +748,26 @@ class HeaderVisitor(BaseVisitor):
     def generic_visit(self, node):
         raise Exception(node)
 
+def create_class_init(class_name, member_names, member_types, member_values):
+    params = []
+    body = []
+
+    for member_name, member_type, member_value in zip(member_names,
+                                                      member_types,
+                                                      member_values):
+        params.append(f'{member_type} {member_name}')
+        body.append(f'this->{member_name} = {member_name};')
+
+    params = ', '.join(params)
+    body = '\n'.join(body)
+
+    return '\n'.join([
+        f'{class_name}({params})',
+        '{',
+        indent(body),
+        '}'
+    ])
+
 def create_class_str(class_name, member_names):
     members = [f'ss << "{name}=" << this->{name}' for name in member_names]
     members = indent(' << ", ";\n'.join(members))
@@ -643,8 +790,8 @@ def create_class_str(class_name, member_names):
 
 class SourceVisitor(BaseVisitor):
 
-    def __init__(self, module_hpp, skip_tests, namespace):
-        super().__init__()
+    def __init__(self, module_hpp, skip_tests, namespace, source_lines):
+        super().__init__(source_lines)
         self.module_hpp = module_hpp
         self.skip_tests = skip_tests
         self.namespace = namespace
@@ -676,7 +823,8 @@ class SourceVisitor(BaseVisitor):
                 'int package_main(int argc, const char *argv[])',
                 '{',
                 f'    return {self.namespace}::main(argc, argv);',
-                '}'
+                '}',
+                ''
             ])
         else:
             return ''
@@ -690,16 +838,48 @@ class SourceVisitor(BaseVisitor):
     def visit_ClassDef(self, node):
         class_name = node.name
         members = []
+        member_types = []
         member_names = []
+        member_values = []
         method_names = []
         body = []
 
         for item in node.body:
             if isinstance(item, ast.FunctionDef):
                 body.append(indent(MethodVisitor(class_name,
-                                                 members,
+                                                 method_names,
+                                                 self.source_lines).visit(item)))
+            elif isinstance(item, ast.AnnAssign):
+                member_name = self.visit(item.target)
+                member_type = self.visit(item.annotation)
+
+                if item.value is not None:
+                    member_value = self.visit(item.value)
+                elif member_type in ['i8', 'i16', 'i32', 'i64']:
+                    member_value = "0"
+                elif member_type in ['u8', 'u16', 'u32', 'u64']:
+                    member_value = "0"
+                elif member_type in ['f32', 'f64']:
+                    member_value = "0.0"
+                elif member_type == 'string':
+                    member_value = 'String()'
+                elif member_type == 'bytes':
+                    member_value = "Bytes()"
+                elif member_type == 'bool':
+                    member_value = "false"
+                else:
+                    member_value = 'std::nullptr'
+
+                members.append(f'{member_type} {member_name};')
+                member_types.append(member_type)
+                member_names.append(member_name)
+                member_values.append(member_value)
+
+        if '__init__' not in method_names:
+            body.append(indent(create_class_init(class_name,
                                                  member_names,
-                                                 method_names).visit(item)))
+                                                 member_types,
+                                                 member_values)))
 
         if '__str__' not in method_names:
             body.append(indent(create_class_str(class_name, member_names)))
@@ -715,15 +895,15 @@ class SourceVisitor(BaseVisitor):
     def visit_FunctionDef(self, node):
         function_name = node.name
         return_type = return_type_string(node.returns)
-        params = params_string(function_name, node.args.args)
+        params = params_string(function_name, node.args.args, self.source_lines)
         body = []
         body_iter = iter(node.body)
 
-        if has_docstring(node):
+        if self.has_docstring(node):
             next(body_iter)
 
         for item in body_iter:
-            body.append(indent(BodyVisitor().visit(item)))
+            body.append(indent(BodyVisitor(self.source_lines).visit(item)))
 
         if function_name == 'main':
             self.add_package_main = True
@@ -733,8 +913,8 @@ class SourceVisitor(BaseVisitor):
             else:
                 raise Exception("main() must return 'None'.")
 
-            if params not in ['List<String>& args', 'void']:
-                raise Exception("main() takes 'args: [str]' or no arguments.")
+            if params not in ['List<String>& argv', 'void']:
+                raise Exception("main() takes 'argv: [string]' or no arguments.")
 
             if params == 'void':
                 body = [indent('\n'.join([
@@ -742,7 +922,7 @@ class SourceVisitor(BaseVisitor):
                     '(void)__argv;'
                 ]))] + body
             else:
-                body = [indent('auto args = create_args(__argc, __argv);')] + body
+                body = [indent('auto argv = create_args(__argc, __argv);')] + body
 
             params = 'int __argc, const char *__argv[]'
             body += ['', indent('return 0;')]
@@ -783,7 +963,7 @@ class SourceVisitor(BaseVisitor):
 
         return code
 
-    def handle_string_source(self, value):
+    def handle_string_source(self, node, value):
         if value.startswith('mys-embedded-c++-before-namespace'):
             self.before_namespace.append('\n'.join([
                 '/* mys-embedded-c++-before-namespace start */\n',
@@ -792,57 +972,83 @@ class SourceVisitor(BaseVisitor):
 
             return ''
         else:
-            return handle_string(value)
+            return self.handle_string_node(node, value)
 
     def visit_Constant(self, node):
         if isinstance(node.value, str):
-            return self.handle_string_source(node.value)
+            return self.handle_string_source(node, node.value)
         else:
             return super().visit_Constant(node)
 
     def visit_Str(self, node):
-        return self.handle_string_source(node.s)
+        if self.is_string(node):
+            return self.handle_string_source(node, node.s)
+        else:
+            raise LanguageError('character literals are not yet supported',
+                                node.lineno,
+                                node.col_offset)
 
     def generic_visit(self, node):
         raise Exception(node)
 
-class MethodVisitor(ast.NodeVisitor):
+class MethodVisitor(BaseVisitor):
 
-    def __init__(self, class_name, members, member_names, method_names):
-        super().__init__()
+    def __init__(self, class_name, method_names, source_lines):
+        super().__init__(source_lines)
         self._class_name = class_name
-        self._members = members
-        self._member_names = member_names
         self._method_names = method_names
 
+    def validate_operator_signature(self,
+                                    method_name,
+                                    params,
+                                    return_type,
+                                    node):
+        expected_return_type = {
+            '__add__': self._class_name,
+            '__sub__': self._class_name,
+            '__iadd__': 'void',
+            '__isub__': 'void',
+            '__eq__': 'bool',
+            '__ne__': 'bool',
+            '__gt__': 'bool',
+            '__ge__': 'bool',
+            '__lt__': 'bool',
+            '__le__': 'bool'
+        }[method_name]
+
+        if return_type != expected_return_type:
+            raise LanguageError(
+                f'{method_name}() must return {expected_return_type}',
+                node.lineno,
+                node.col_offset)
+
     def visit_FunctionDef(self, node):
         method_name = node.name
         return_type = return_type_string(node.returns)
 
-        if len(node.args.args) == 0 or node.args.args[0].arg != 'self':
-            raise Exception(
-                "Methods must always take 'self' as their first argument.")
-
         if node.decorator_list:
             raise Exception("Methods must not be decorated.")
 
-        params = params_string(method_name, node.args.args[1:])
+        if len(node.args.args) == 0 or node.args.args[0].arg != 'self':
+            raise LanguageError(
+                'Methods must take self as their first argument.',
+                node.lineno,
+                node.col_offset)
+
+        params = params_string(method_name, node.args.args[1:], self.source_lines)
         body = []
         body_iter = iter(node.body)
 
-        if has_docstring(node):
+        if self.has_docstring(node):
             next(body_iter)
 
         for item in body_iter:
-            body.append(indent(BodyVisitor().visit(item)))
+            body.append(indent(BodyVisitor(self.source_lines).visit(item)))
 
         body = '\n'.join(body)
         self._method_names.append(method_name)
 
         if method_name == '__init__':
-            for item in node.body:
-                InitMemberVisitor(self._members, self._member_names).visit(item)
-
             return '\n'.join([
                 f'{self._class_name}({params})',
                 '{',
@@ -850,14 +1056,22 @@ class MethodVisitor(ast.NodeVisitor):
                 '}'
             ])
         elif method_name == '__del__':
-            raise LanguageError('__del__ is not yet supported')
-        else:
-            return '\n'.join([
-                f'{return_type} {method_name}({params})',
-                '{',
-                body,
-                '}'
-            ])
+            raise LanguageError('__del__ is not yet supported',
+                                node.lineno,
+                                node.col_offset)
+        elif method_name in METHOD_OPERATORS:
+            self.validate_operator_signature(method_name,
+                                             params,
+                                             return_type,
+                                             node)
+            method_name = 'operator' + METHOD_OPERATORS[method_name]
+
+        return '\n'.join([
+            f'{return_type} {method_name}({params})',
+            '{',
+            body,
+            '}'
+        ])
 
     def generic_visit(self, node):
         raise Exception(node)
@@ -865,29 +1079,10 @@ class MethodVisitor(ast.NodeVisitor):
 class BodyVisitor(BaseVisitor):
     pass
 
-class InitMemberVisitor(BaseVisitor):
-
-    def __init__(self, members, member_names):
-        super().__init__()
-        self._members = members
-        self._member_names = member_names
-
-    def visit_AnnAssign(self, node):
-        if not isinstance(node.target, ast.Attribute):
-            return
-
-        if node.target.value.id != 'self':
-            return
-
-        member_type = self.visit(node.annotation)
-        member_name = node.target.attr
-        self._members.append(f'{member_type} {member_name};')
-        self._member_names.append(member_name)
-
 class ParamVisitor(BaseVisitor):
 
-    def __init__(self, function_name):
-        super().__init__()
+    def __init__(self, function_name, source_lines):
+        super().__init__(source_lines)
         self.function_name = function_name
 
     def visit_arg(self, node):
@@ -899,7 +1094,7 @@ class ParamVisitor(BaseVisitor):
         elif isinstance(annotation, ast.Name):
             param_type = annotation.id
 
-            if param_type == 'str':
+            if param_type == 'string':
                 param_type = 'String&'
             elif param_type not in PRIMITIVE_TYPES:
                 param_type = f'std::shared_ptr<{param_type}>&'
@@ -920,7 +1115,7 @@ class ParamVisitor(BaseVisitor):
             else:
                 param_type = annotation.elts[0].id
 
-                if param_type == 'str':
+                if param_type == 'string':
                     param_type = 'String'
                 elif param_type not in PRIMITIVE_TYPES:
                     param_type = f'std::shared_ptr<{param_type}>'
@@ -932,7 +1127,7 @@ class ParamVisitor(BaseVisitor):
             for item in annotation.elts:
                 param_type = item.id
 
-                if param_type == 'str':
+                if param_type == 'string':
                     param_type = 'String'
                 elif param_type not in PRIMITIVE_TYPES:
                     param_type = f'std::shared_ptr<{param_type}>'
@@ -967,13 +1162,18 @@ def style_traceback(traceback):
 
 def transpile(source, filename, module_hpp, skip_tests=False):
     namespace = 'mys::' + module_hpp[:-8].replace('/', '::')
+    module_levels = module_hpp[:-8].split('/')
+    source_lines = source.split('\n')
 
     try:
-        header = HeaderVisitor(namespace).visit(ast.parse(source, filename))
+        header = HeaderVisitor(namespace,
+                               module_levels,
+                               source_lines).visit(ast.parse(source, filename))
         source = SourceVisitor(module_hpp,
                                skip_tests,
-                               namespace).visit(ast.parse(source,
-                                                          filename))
+                               namespace,
+                               source_lines).visit(ast.parse(source,
+                                                             filename))
 
         return header, source
     except SyntaxError:
